@@ -53,10 +53,8 @@ def normalize_chromosome(c):
 
 
 def normalize_strand(strand):
-    if strand == "+" or strand == "-":
-        return strand
-    elif strand == 1:
+    if strand == "+" or strand == 1 or strand == "+1" or strand == "1" :
         return "+"
-    elif strand == -1:
+    elif strand == "-" or strand == -1 or strand == "-1":
         return "-"
     raise ValueError("Invalid strand: %s" % (strand,))
